from werkzeug.test import EnvironBuilder
from blaze_net.app import app

def test_index():
    builder = EnvironBuilder(path='/', method='GET')
    environ = builder.get_environ()
    response = app(environ, lambda *args: None)
    assert response.status_code == 200
    assert b"Welcome to BlazeNet!" in response.data


from sqlalchemy import create_engine, MetaData
from sqlalchemy.orm import sessionmaker
from sqlalchemy.ext.declarative import declarative_base

class ModelManager:
    Base = declarative_base()
    def __init__(self, database_url='sqlite:///blazenet.db'):
        self.engine = create_engine(database_url, echo=True)
        self.Base = declarative_base(bind=self.engine)
        self.Session = sessionmaker(bind=self.engine)
        self.metadata = MetaData(bind=self.engine)

    def create_all(self):
        self.Base.metadata.create_all(self.engine)

    def drop_all(self):
        self.Base.metadata.drop_all(self.engine)

    def migrate(self, model):
        model.__table__.create(self.engine, checkfirst=True)

    def rollback(self, model):
        model.__table__.drop(self.engine, checkfirst=True)

    def get_session(self):
        return self.Session()

    def get_engine(self):
        return self.engine


from setuptools import setup, find_packages

setup(
    name='blaze-net',
    version='1.1.1',
    author='McLovinAlan69',
    author_email='gameg1676@gmail.com',
    description='A Python web framework',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/Alan69/blaze_net',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: CGI Tools/Libraries',
    ],
    install_requires=[
        'werkzeug',
        'jinja2',
        'sqlalchemy',
    ],
)



import os
from werkzeug.exceptions import HTTPException, NotFound
from werkzeug.wrappers import Request, Response
from werkzeug.routing import Map, Rule
from jinja2 import Environment, FileSystemLoader
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from werkzeug.serving import run_simple
import json

class BlazeNet:
    def __init__(self, template_path='blaze_net/templates/', static_path='static', database_url='sqlite:///blazenet.db'):
        self.url_map = Map()
        self.template_env = Environment(loader=FileSystemLoader(template_path))
        self.engine = create_engine(database_url, echo=True)
        self.Session = sessionmaker(bind=self.engine)
        self.static_path = static_path

    def route(self, rule):
        def decorator(f):
            def wrapper(*args, **kwargs):
                return f(*args, **kwargs)
            rule_obj = Rule(rule, endpoint=f)
            self.url_map.add(rule_obj)
            return wrapper
        return decorator

    def __call__(self, environ, start_response):
        request = Request(environ)
        if request.path.startswith('/static/'):
            return self.serve_static(environ, start_response)
        else:
            response = self.dispatch_request(request)
            if isinstance(response, str):
                response = Response(response, content_type='text/html')
            return response(environ, start_response)
        
    def json_response(self, data, status_code=200):
        json_data = json.dumps(data)
        return Response(json_data, status=status_code, content_type='application/json')

    def serve_static(self, environ, start_response):
        path = environ['PATH_INFO']
        if path.startswith('/static/'):
            full_path = os.path.join(self.static_path, path.lstrip('/static/'))
            if os.path.exists(full_path) and os.path.isfile(full_path):
                with open(full_path, 'rb') as f:
                    content = f.read()
                mime_type = self.get_mimetype(full_path)
                response = Response(content, mimetype=mime_type)
                return response(environ, start_response)
        raise NotFound()

    def get_mimetype(self, path):
        mime_types = {
            '.css': 'text/css',
            '.js': 'application/javascript',
            '.png': 'image/png',
            '.jpg': 'image/jpeg',
            '.jpeg': 'image/jpeg',
            '.gif': 'image/gif',
            '.svg': 'image/svg+xml'
        }
        _, ext = os.path.splitext(path)
        return mime_types.get(ext.lower(), 'application/octet-stream')

    def dispatch_request(self, request):
        adapter = self.url_map.bind_to_environ(request.environ)
        try:
            endpoint, values = adapter.match()
            return endpoint(request, **values)
        except HTTPException as e:
            # Handle HTTP exceptions
            return e

    def wsgi_app(self, environ, start_response):
        request = Request(environ)
        response = self.dispatch_request(request)
        if isinstance(response, str):
            response = Response(response, content_type='text/html')
        return response(environ, start_response)

    def run(self, host='localhost', port=5000, use_reloader=False):
        run_simple(host, port, self.wsgi_app, use_reloader=use_reloader)
